@@ -104,7 +104,7 @@ void AmarokCatalog::queryChanged()
 					newStatus = 0;
 				} else {
 					TQDataStream reply(replyData, IO_ReadOnly);
-					if (replyType == TQSTRINGLIST_OBJECT_NAME_STRING) {
+					if (replyType == "TQStringList") {
 						TQStringList sqlResult;
 						reply >> sqlResult;
 					
@@ -179,7 +179,7 @@ void AmarokCatalog::queryChanged()
 					newStatus = 0;
 				} else {
 					TQDataStream reply(replyData, IO_ReadOnly);
-					if (replyType == TQSTRINGLIST_OBJECT_NAME_STRING) {
+					if (replyType == "TQStringList") {
 						TQStringList sqlResult;
 						reply >> sqlResult;
 					
@@ -281,7 +281,7 @@ void AmarokCatalog::checkCollectionType()
 	else
 	{
 		TQDataStream reply(replyData, IO_ReadOnly);
-		if (replyType == TQSTRINGLIST_OBJECT_NAME_STRING)
+		if (replyType == "TQStringList")
 		{
 			TQStringList sqlResult;
 			reply >> sqlResult;
