@@ -34,9 +34,9 @@
 
 #include "settings.h"
 #include "googlecatalog.h"
-#include "actionregistry.h"
+#include <actionregistry.h>
 #include "actionsearch.h"
-#include "status.h"
+#include <status.h>
 
 K_EXPORT_COMPONENT_FACTORY( katapult_googlecatalog,
                             KGenericFactory<GoogleCatalog>( "katapult_googlecatalog" ) )
