@@ -29,7 +29,7 @@
 */
 class Program : public KatapultItem
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	
